@@ -1,8 +1,8 @@
 C Output from Public domain Ratfor, version 1.0
       subroutine dppll(x,y,l1,l2,l3,l4,np,nl,eps,mint,rslt,xmin,jmin)
       implicit double precision(a-h,o-z)
-      dimension x(1), y(1), rslt(np,1), xmin(1), jmin(1)
-      double precision l1(1), l2(1), l3(1), l4(1)
+      dimension x(*), y(*), rslt(np,*), xmin(*), jmin(*)
+      double precision l1(*), l2(*), l3(*), l4(*)
       one = 1.d0
       zero = 0.d0
       do23000 j = 1,nl 
